@@ -1,4 +1,4 @@
-#!C:\bld\compliance-checker_1523715871092\_h_env\python.exe
+#!C:\bld\compliance-checker_1550593031990\_h_env\python.exe
 from __future__ import print_function
 
 import argparse
@@ -6,6 +6,7 @@ import sys
 from compliance_checker.runner import ComplianceChecker, CheckSuite
 from compliance_checker.cf.util import download_cf_standard_name_table
 from compliance_checker import __version__
+from textwrap import dedent
 
 
 def main():
@@ -33,7 +34,20 @@ def main():
                         default=0)
 
     parser.add_argument('--skip-checks', '-s',
-                        help="Specifies tests to skip",
+                        help=dedent("""
+                                    Specifies tests to skip. Can take the form
+                                    of either `<check_name>` or
+                                    `<check_name>:<skip_level>`.  The first
+                                    form skips any checks matching the name.
+                                    In the second form <skip_level> may be
+                                    specified as "A", "M", or "L".  "A" skips
+                                    all checks and is equivalent to calling
+                                    the first form. "M" will only show high
+                                    priority output from the given check and
+                                    will skip medium and low.  "L" will show
+                                    both high and medium priority issues, while
+                                    skipping low priority issues.
+                                    """),
                         action='append')
 
     parser.add_argument('-f', '--format', default=[], action='append',
@@ -43,7 +57,8 @@ def main():
                               " key, whereas the 'json_new' format has the dataset name(s) as the"
                               " main key in the output follow by any checks as subkeys.  Also, "
                               "'json' format can be only be run against one input file, whereas "
-                              "'json_new' can be run against multiple files."))
+                              "'json_new' can be run against multiple files."),
+                        choices=['text', 'html', 'json', 'json_new'])
 
     parser.add_argument('-o', '--output', default=[], action='append',
                         help=("Output filename(s).  If '-' is supplied, output to stdout."
@@ -67,8 +82,13 @@ def main():
                         help=("Specify a version of the cf standard name table"
                               " to download as packaged version"))
 
+    # Add command line args from generator plugins
+    check_suite.add_plugin_args(parser)
+
     args = parser.parse_args()
 
+    check_suite.load_generated_checkers(args)
+
     if args.version:
         print("IOOS compliance checker version %s" % __version__)
         return 0
@@ -87,6 +107,10 @@ def main():
     if args.download_standard_names:
         download_cf_standard_name_table(args.download_standard_names)
 
+    if len(args.dataset_location) == 0:
+        parser.print_help()
+        return 1
+
     # Check the number of output files
     if not args.output:
         args.output = '-'
@@ -95,14 +119,6 @@ def main():
         print('The number of output files must either be one or the same as the number of datasets', file=sys.stderr)
         sys.exit(2)
 
-    # Check the output formats
-    format_choices = ['text', 'html', 'json', 'json_new']
-    for out_format in args.format:
-        if out_format not in format_choices:
-            print(("Error: argument -f/--format: invalid choice: '{}'"
-                   " (choose from 'text', 'html', 'json', 'json_new')".format(out_format)))
-            sys.exit(2)
-
     # Run the compliance checker
     # 2 modes, concatenated output file or multiple output files
     return_values = []
