@@ -6,16 +6,15 @@ project for the verification and scoring of attributes for datasets.
 '''
 
 from __future__ import unicode_literals
-
 import numpy as np
 from netCDF4 import num2date
 from datetime import timedelta
-
 from compliance_checker.base import (BaseCheck, BaseNCCheck, check_has,
-                                     score_group, Result, ratable_result)
+                                     Result, ratable_result)
 from compliance_checker.cf.util import _possiblexunits, _possibleyunits
 from compliance_checker.util import datetime_is_iso, dateparse
 from compliance_checker import cfutil
+import pendulum
 from pygeoif import from_wkt
 
 
@@ -24,6 +23,11 @@ class ACDDBaseCheck(BaseCheck):
     _cc_spec = 'acdd'
     _cc_description = 'Attribute Conventions for Dataset Discovery (ACDD)'
     _cc_url = 'http://wiki.esipfed.org/index.php?title=Category:Attribute_Conventions_Dataset_Discovery'
+    _cc_display_headers = {
+        3: 'Highly Recommended',
+        2: 'Recommended',
+        1: 'Suggested'
+    }
 
     def __init__(self):
 
@@ -77,8 +81,11 @@ class ACDDBaseCheck(BaseCheck):
         # the method isn't executed repeatedly.
         self._applicable_variables = None
 
+        # to be used to format variable Result groups headers
+        self._var_header = "variable \"{}\" missing the following attributes:"
+
     # set up attributes according to version
-    @check_has(BaseCheck.HIGH)
+    @check_has(BaseCheck.HIGH, gname="Global Attributes")
     def check_high(self, ds):
         '''
         Performs a check on each highly recommended attributes' existence in the dataset
@@ -87,7 +94,7 @@ class ACDDBaseCheck(BaseCheck):
         '''
         return self.high_rec_atts
 
-    @check_has(BaseCheck.MEDIUM)
+    @check_has(BaseCheck.MEDIUM, gname="Global Attributes")
     def check_recommended(self, ds):
         '''
         Performs a check on each recommended attributes' existence in the dataset
@@ -96,8 +103,13 @@ class ACDDBaseCheck(BaseCheck):
         '''
         return self.rec_atts
 
-    @check_has(BaseCheck.LOW)
+    @check_has(BaseCheck.LOW, gname="Global Attributes")
     def check_suggested(self, ds):
+        '''
+        Performs a check on each suggested attributes' existence in the dataset
+
+        :param netCDF4.Dataset ds: An open netCDF dataset
+        '''
         return self.sug_atts
 
     def get_applicable_variables(self, ds):
@@ -111,20 +123,21 @@ class ACDDBaseCheck(BaseCheck):
         if self._applicable_variables is None:
             self.applicable_variables = cfutil.get_geophysical_variables(ds)
             varname = cfutil.get_time_variable(ds)
-            if varname:
+            # avoid duplicates by checking if already present
+            if varname and (varname not in self.applicable_variables):
                 self.applicable_variables.append(varname)
             varname = cfutil.get_lon_variable(ds)
-            if varname:
+            if varname and (varname not in self.applicable_variables):
                 self.applicable_variables.append(varname)
             varname = cfutil.get_lat_variable(ds)
-            if varname:
+            if varname and (varname not in self.applicable_variables):
                 self.applicable_variables.append(varname)
             varname = cfutil.get_z_variable(ds)
-            if varname:
+            if varname and (varname not in self.applicable_variables):
                 self.applicable_variables.append(varname)
+
         return self.applicable_variables
 
-    @score_group('varattr')
     def check_var_long_name(self, ds):
         '''
         Checks each applicable variable for the long_name attribute
@@ -141,12 +154,11 @@ class ACDDBaseCheck(BaseCheck):
             long_name = getattr(ds.variables[variable], 'long_name', None)
             check = long_name is not None
             if not check:
-                msgs.append("Var %s missing attr long_name" % variable)
-            results.append(Result(BaseCheck.HIGH, check, (variable, "var_std_name"), msgs))
+                msgs.append("long_name")
+            results.append(Result(BaseCheck.HIGH, check, self._var_header.format(variable), msgs))
 
         return results
 
-    @score_group('varattr')
     def check_var_standard_name(self, ds):
         '''
         Checks each applicable variable for the standard_name attribute
@@ -159,12 +171,11 @@ class ACDDBaseCheck(BaseCheck):
             std_name = getattr(ds.variables[variable], 'standard_name', None)
             check = std_name is not None
             if not check:
-                msgs.append("Var %s missing attr standard_name" % variable)
-            results.append(Result(BaseCheck.HIGH, check, (variable, "var_std_name"), msgs))
+                msgs.append("standard_name")
+            results.append(Result(BaseCheck.HIGH, check, self._var_header.format(variable), msgs))
 
         return results
 
-    @score_group('varattr')
     def check_var_units(self, ds):
         '''
         Checks each applicable variable for the units attribute
@@ -182,14 +193,16 @@ class ACDDBaseCheck(BaseCheck):
                 continue
             # Check if we have no units
             if not unit_check:
-                msgs.append("Var %s missing attr units" % variable)
-            results.append(Result(BaseCheck.HIGH, unit_check, (variable, "var_units"), msgs))
+                msgs.append("units")
+            results.append(Result(BaseCheck.HIGH, unit_check, self._var_header.format(variable), msgs))
 
         return results
 
     def check_acknowledgment(self, ds):
         '''
-        Check if acknowledgment/acknowledgment attr is present.
+        Check if acknowledgment/acknowledgment attribute is present. Because
+        acknowledgement has its own check, we are keeping it out of the Global
+        Attributes (even though it is a Global Attr).
 
         :param netCDF4.Dataset ds: An open netCDF dataset
         '''
@@ -198,9 +211,10 @@ class ACDDBaseCheck(BaseCheck):
         if hasattr(ds, 'acknowledgment') or hasattr(ds, 'acknowledgement'):
             check = True
         else:
-            messages.append("acknowledgement global attribute is recommended")
+            messages.append("acknowledgment/acknowledgement not present")
 
-        return Result(BaseCheck.MEDIUM, check, 'acknowledgment/acknowledgement', msgs=messages)
+        # name="Global Attributes" so gets grouped with Global Attributes
+        return Result(BaseCheck.MEDIUM, check, "Global Attributes", msgs=messages)
 
     def check_lat_extents(self, ds):
         '''
@@ -340,8 +354,8 @@ class ACDDBaseCheck(BaseCheck):
         check = var is not None
         if not check:
             return ratable_result(False,
-                                  'geospatial_bounds',
-                                  ["Attr geospatial_bounds not present"])
+                                  "Global Attributes", # grouped with Globals
+                                  ["geospatial_bounds not present"])
 
         try:
             # TODO: verify that WKT is valid given CRS (defaults to EPSG:4326
@@ -349,11 +363,11 @@ class ACDDBaseCheck(BaseCheck):
             from_wkt(ds.geospatial_bounds)
         except AttributeError:
             return ratable_result(False,
-                                  'geospatial_bounds',
+                                  "Global Attributes", # grouped with Globals
                                   ['Could not parse WKT, possible bad value for WKT'])
         # parsed OK
         else:
-            return ratable_result(True, 'geospatial_bounds', tuple())
+            return ratable_result(True, "Global Attributes", tuple())
 
     def _check_total_z_extents(self, ds, z_variable):
         '''
@@ -452,7 +466,7 @@ class ACDDBaseCheck(BaseCheck):
         if not (hasattr(ds, 'time_coverage_start') and hasattr(ds, 'time_coverage_end')):
             return
 
-        # allows non-ISO 8601 formatted dates
+        # Parse the ISO 8601 formatted dates
         try:
             t_min = dateparse(ds.time_coverage_start)
             t_max = dateparse(ds.time_coverage_end)
@@ -460,7 +474,7 @@ class ACDDBaseCheck(BaseCheck):
             return Result(BaseCheck.MEDIUM,
                           False,
                           'time_coverage_extents_match',
-                          ['time_coverage variables are not formatted properly. Please ensure they are valid ISO-8601 time strings'])
+                          ['time_coverage attributes are not formatted properly. Use the ISO 8601:2004 date format, preferably the extended format.'])
 
         timevar = cfutil.get_time_variable(ds)
 
@@ -472,8 +486,15 @@ class ACDDBaseCheck(BaseCheck):
 
         # Time should be monotonically increasing, so we make that assumption here so we don't have to download THE ENTIRE ARRAY
         try:
-            time0 = num2date(ds.variables[timevar][0], ds.variables[timevar].units)
-            time1 = num2date(ds.variables[timevar][-1], ds.variables[timevar].units)
+            # num2date returns as naive date, but with time adjusted to UTC
+            # we need to attach timezone information here, or the date
+            # subtraction from t_min/t_max will assume that a naive timestamp is
+            # in the same time zone and cause erroneous results.
+            # Pendulum uses UTC by default, but we are being explicit here
+            time0 = pendulum.instance(num2date(ds.variables[timevar][0],
+                                      ds.variables[timevar].units), 'UTC')
+            time1 = pendulum.instance(num2date(ds.variables[timevar][-1],
+                                      ds.variables[timevar].units), 'UTC')
         except:
             return Result(BaseCheck.MEDIUM,
                           False,
@@ -503,19 +524,19 @@ class ACDDBaseCheck(BaseCheck):
         """
         Verify that the version in the Conventions field is correct
         """
-        for convention in ds.Conventions.replace(' ', '').split(','):
-            if convention == 'ACDD-' + self._cc_spec_version:
-                return ratable_result((2, 2),
-                                      'Conventions',
-                                      [])
-        # Conventions attribute is present, but does not include
-        # proper ACDD version
-        messages = [
-            "Attr Conventions does not contain 'ACDD-{}'".format(self._cc_spec_version)
-        ]
-        return ratable_result((1, 2),
-                              'Conventions',
-                              messages)
+        try:
+            for convention in getattr(ds, "Conventions", '').replace(' ', '').split(','):
+                if convention == 'ACDD-' + self._cc_spec_version:
+                    return ratable_result((2, 2), None, []) # name=None so grouped with Globals
+
+            # if no/wrong ACDD convention, return appropriate result
+            # Result will have name "Global Attributes" to group with globals
+            m = ["Conventions does not contain 'ACDD-{}'".format(self._cc_spec_version)]
+            return ratable_result((1, 2), "Global Attributes", m)
+        except AttributeError: # NetCDF attribute not found
+            m = ["No Conventions attribute present; must contain ACDD-{}".format(self._cc_spec_version)]
+            # Result will have name "Global Attributes" to group with globals
+            return ratable_result((0, 2), "Global Attributes", m)
 
 
 class ACDDNCCheck(BaseNCCheck, ACDDBaseCheck):
@@ -554,7 +575,8 @@ class ACDD1_3Check(ACDDNCCheck):
             ('Conventions', self.verify_convention_version)
         ])
 
-        self.rec_atts.extend(['geospatial_vertical_positive',
+        self.rec_atts.extend([
+                              'geospatial_vertical_positive',
                               'geospatial_bounds_crs',
                               'geospatial_bounds_vertical_crs',
                               'publisher_name',       # publisher,dataCenter
@@ -663,7 +685,6 @@ class ACDD1_3Check(ACDDNCCheck):
         return Result(BaseCheck.MEDIUM, date_created_check,
                       'date_created_is_iso', msgs)
 
-    @score_group('varattr')
     def check_var_coverage_content_type(self, ds):
         '''
         Check coverage content type against valid ISO-19115-1 codes
@@ -677,11 +698,9 @@ class ACDD1_3Check(ACDDNCCheck):
                             'coverage_content_type', None)
             check = ctype is not None
             if not check:
-                msgs.append("Var %s missing attr coverage_content_type" %
-                            variable)
+                msgs.append("coverage_content")
                 results.append(Result(BaseCheck.HIGH, check,
-                                      (variable, "coverage_content_type"),
-                                      msgs))
+                                      self._var_header.format(variable), msgs))
                 continue
 
             # ISO 19115-1 codes
@@ -696,7 +715,9 @@ class ACDD1_3Check(ACDDNCCheck):
                 'coordinate'
             }
             if ctype not in valid_ctypes:
-                msgs.append("Var %s does not have a coverage_content_type in %s"
+                msgs.append("coverage_content_type in \"%s\""
                             % (variable, sorted(valid_ctypes)))
+                results.append(Result(BaseCheck.HIGH, check, # append to list
+                                      self._var_header.format(variable), msgs))
 
         return results
