@@ -1,6 +1,9 @@
+from __future__ import print_function
+import io
 import itertools
 import requests
 import os
+import sys
 from copy import deepcopy
 from collections import defaultdict
 from lxml import etree
@@ -11,7 +14,7 @@ from pkg_resources import resource_filename
 
 # copied from paegan
 # paegan may depend on these later
-_possiblet = ["time", "TIME", "Time",
+_possiblet = {"time", "TIME", "Time",
               "t", "T",
               "ocean_time", "OCEAN_TIME",
               "jd", "JD",
@@ -19,8 +22,8 @@ _possiblet = ["time", "TIME", "Time",
               "times", "TIMES", "Times",
               "mt", "MT",
               "dt", "DT",
-              ]
-_possiblez = ["depth", "DEPTH",
+              }
+_possiblez = {"depth", "DEPTH",
               "depths", "DEPTHS",
               "height", "HEIGHT",
               "altitude", "ALTITUDE",
@@ -34,8 +37,8 @@ _possiblez = ["depth", "DEPTH",
               "siglev", "SIGLEV",
               "sigma", "SIGMA",
               "vertical", "VERTICAL", "lev", "LEV", "level", "LEVEL"
-              ]
-_possiblex = ["x", "X",
+              }
+_possiblex = {"x", "X",
               "lon", "LON",
               "xlon", "XLON",
               "lonx", "lonx",
@@ -46,9 +49,8 @@ _possiblex = ["x", "X",
               "longitude", "LONGITUDE",
               "lon_rho", "LON_RHO",
               "lon_psi", "LON_PSI",
-
-              ]
-_possibley = ["y", "Y",
+              }
+_possibley = {"y", "Y",
               "lat", "LAT",
               "ylat", "YLAT",
               "laty", "laty",
@@ -60,28 +62,28 @@ _possibley = ["y", "Y",
               "lat_rho", "LAT_RHO",
               "lat_psi", "LAT_PSI",
 
-              ]
+              }
 
-_possibleaxis = _possiblet + _possiblez + _possiblex + _possibley
+_possibleaxis = _possiblet | _possiblez | _possiblex | _possibley
 
 
-_possiblexunits = ['degrees_east',
+_possiblexunits = {'degrees_east',
                    'degree_east',
                    'degrees_E',
                    'degree_E',
                    'degreesE',
                    'degreeE'
-                   ]
+                   }
 
-_possibleyunits = ['degrees_north',
+_possibleyunits = {'degrees_north',
                    'degree_north',
                    'degrees_N',
                    'degree_N',
                    'degreesN',
                    'degreeN'
-                   ]
+                   }
 
-_possibletunits = ['day',
+_possibletunits = {'day',
                    'days',
                    'd',
                    'hour',
@@ -101,9 +103,9 @@ _possibletunits = ['day',
                    's',
                    'sec',
                    'secs'
-                   ]
+                   }
 
-_possibleaxisunits = _possiblexunits + _possibleyunits + _possibletunits
+_possibleaxisunits = _possiblexunits | _possibleyunits | _possibletunits
 
 
 class DotDict(dict):
@@ -260,11 +262,11 @@ class StandardNameTable(object):
 
     def __init__(self, cached_location=None):
         if cached_location:
-            try:
-                with open(cached_location, 'r') as fp:
-                    resource_text = fp.read()
-            except Exception:
-                resource_text = get_data("compliance_checker", "data/cf-standard-name-table.xml")
+            with io.open(cached_location, 'r', encoding='utf-8') as fp:
+                resource_text = fp.read()
+        elif os.environ.get('CF_STANDARD_NAME_TABLE') and os.path.exists(os.environ['CF_STANDARD_NAME_TABLE']):
+            with io.open(os.environ['CF_STANDARD_NAME_TABLE'], 'r', encoding='utf-8') as fp:
+                resource_text = fp.read()
         else:
             resource_text = get_data("compliance_checker", "data/cf-standard-name-table.xml")
 
@@ -329,13 +331,14 @@ def download_cf_standard_name_table(version, location=None):
     url = "http://cfconventions.org/Data/cf-standard-names/{0}/src/cf-standard-name-table.xml".format(version)
     r = requests.get(url, allow_redirects=True)
     if r.status_code == 200:
-        print("Downloading cf-standard-names table version {0} from: {1}".format(version, url))
+        print("Downloading cf-standard-names table version {0} from: {1}".format(version, url), file=sys.stderr)
         with open(location, 'wb') as f:
             f.write(r.content)
     else:
         r.raise_for_status()
     return
 
+
 def create_cached_data_dir():
     '''
     Returns the path to the data directory to download CF standard names.
@@ -349,6 +352,7 @@ def create_cached_data_dir():
 
     return data_directory
 
+
 def units_known(units):
     try:
         Unit(units)
